// Order.cpp: implementation of the COrder class.
//
//////////////////////////////////////////////////////////////////////

#include "StdAfx.h"

#include "CustomDrawing.h"
#include "Order.h"
#include "ProductManager.h"
#include <Dapfor/Common/LongEnumFormat.h>
#include <Dapfor/Common/DoubleFormat.h>
#include <Dapfor/Common/LongDateFormat.h>


#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif



//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

Dapfor::Common::CLongEnumFormat::Item status[] =
{
    {COrder::Ordered,   _T("Ordered")},
    {COrder::Payed,     _T("Payed")},
    {COrder::Refunded,  _T("Refunded")},
    {COrder::Cancelled, _T("Cancelled")},
};



DF_BEGIN_FIELD_MAP(COrder)
    //The field of the data object handles the life cycle of the format and destroys it in the destructor.
    //Therefore we will give a copy of the format, returned by the CProductManager::GetProductFormat() function.
    DF_ENUM_ID  (FidProduct,    _T("Product"),    &COrder::GetProduct,    0, CProductManager::GetProductFormat().Clone())
    DF_DOUBLE_ID(FidUnitPrice,  _T("UnitPrice"),  &COrder::GetUnitPrice,  0, new CDoubleFormat(3, false, false, 0, _T('$')))
    DF_LONG_ID  (FidCount,      _T("Count"),      &COrder::GetCount,      &COrder::SetCount, 0)
    DF_DOUBLE_ID(FidPrice,      _T("Price"),      &COrder::GetPrice,      0, new CDoubleFormat(3, false, false, 0, _T('$')))
    DF_LONG_ID  (FidTimeStamp,  _T("TimeStamp"),  &COrder::GetTimeStamp,  &COrder::SetTimeStamp, new CLongDateFormat(CLongDateFormat::short_date))
    DF_ENUM_ID  (FidStatus,     _T("Status"),     &COrder::GetStatus,     &COrder::SetStatus, DF_ENUM_FORMAT(status))
    DF_LONG_ID  (FidObjectType, _T("Object type"),&COrder::GetObjectType, 0, 0)
DF_END_FIELD_MAP()


COrder::COrder(CProductManager::Product product, long count, long timeStamp, Status status)
: m_Product(product)
, m_Count(count)
, m_TimeStamp(timeStamp)
, m_Status(status)
{
}

COrder::~COrder()
{
}


CProductManager::Product COrder::GetProduct() const     {return m_Product;}
double                   COrder::GetUnitPrice() const   {return CProductManager::GetUnitPrice(m_Product);}
long                     COrder::GetCount() const       {return m_Count;}
double                   COrder::GetPrice() const       {return GetUnitPrice() * GetCount();}
long                     COrder::GetTimeStamp() const   {return m_TimeStamp;}
COrder::Status           COrder::GetStatus() const      {return m_Status;}


void COrder::SetCount(long count)
{
	m_Count = count;
	NotifyUpdate(FidCount);
	NotifyUpdate(FidPrice);
}

void COrder::SetTimeStamp(long timeStamp)
{
	m_TimeStamp = timeStamp;
	NotifyUpdate(FidTimeStamp);
}

void COrder::SetStatus(COrder::Status status)
{
	m_Status = status;

	//When the status is changed, the whole line in the grid can change the color
	NotifyUpdate(Dapfor::Common::allFields);
}

long COrder::GetObjectType() const
{
	return Order;
}