// MainFrm.h : interface of the CMainFrame class
//
/////////////////////////////////////////////////////////////////////////////
#pragma once


#include "Types.h"
#include "Splitter.h"
#include <Dapfor/GUI/Grid.h>

#include <Dapfor/Common/Automat.h>
#include <Dapfor/Common/SyncObject.h>
#include <Dapfor/Common/Timer.h>


#include <vector>

using namespace Dapfor;

class CTestObject;

class CMainFrame : public CFrameWnd, public Common::CTimer::ICallBack
{
    typedef std::vector<CTestObject*> Container;
    typedef std::vector<Common::CDataObject*> LogMessages;

    
    enum
    {
        TimerId         = 1000,
        TitleUpdateTimerId,
    };

public:
    CMainFrame();
    virtual ~CMainFrame();

    void AddItemsToGrid(UINT count, Location location, Thread thread);
    void RemoveItemsFromGrid(UINT count, Location location, Thread thread);
    void ProcessUpdate(Thread thread);

protected:
    void LogMessage(LogActionType actionType, const CString& message);
    void UpdateTitle();

    //{{AFX_VIRTUAL(CMainFrame)
    virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
    virtual BOOL OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo);
    //}}AFX_VIRTUAL


    //{{AFX_MSG(CMainFrame)
    afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
    afx_msg void OnSetFocus(CWnd *pOldWnd);
    afx_msg void OnAddItems();
    afx_msg void OnRemoveItems();
    afx_msg void OnNotificationsOptimization();
    afx_msg void OnUpdateNotificationsOptimization(CCmdUI* pCmdUI);
    afx_msg void OnOnidleOptimization();
    afx_msg void OnUpdateOnidleOptimization(CCmdUI* pCmdUI);
    afx_msg BOOL OnEraseBkgnd(CDC* pDC);
    afx_msg void OnDestroy();
    afx_msg void OnTimer(UINT nIDEvent);
    afx_msg void OnUpdateSettings();
    afx_msg void OnEnableUpdates();
    afx_msg void OnUpdateEnableUpdates(CCmdUI* pCmdUI);
    afx_msg void OnHighlightAlpha();
    afx_msg void OnUpdateHighlightAlpha(CCmdUI* pCmdUI);
    afx_msg void OnHighlightDisable();
    afx_msg void OnUpdateHighlightDisable(CCmdUI* pCmdUI);
    afx_msg void OnHighlightFading();
    afx_msg void OnUpdateHighlightFading(CCmdUI* pCmdUI);
    afx_msg void OnDoubleBuffering();
    afx_msg void OnUpdateDoubleBuffering(CCmdUI* pCmdUI);
    //}}AFX_MSG


    //Common::CTimer::ICallBack implementation
    virtual void OnExpire(int timerId);

private:  // control bar embedded members
    CImageList  m_ToolbarIcons;
    CToolBar    m_wndToolBar;
    CSplitter   m_wndSplitter;
    GUI::CGrid  m_Grid;
    GUI::CGrid  m_Logger;
    Container   m_TestObjects;
    LogMessages m_LogMessages;
    
    BOOL        m_EnableUpdates;
    Thread      m_UpdatesSource;
    UINT        m_Frequency;
    __int64     m_UpdatedItems;
    long        m_StartTime;
    __int64     m_TotalUpdatedItems;

    long        m_LastCPUUsageTick;
    double      m_LastConsumedTime;
    
    Common::CAutomat m_Thread;      //A thread to process add/remove and update tasks from the non-GUI thread.
    Common::CSyncObject m_Synchro; //Critical section to prevent containers from racing condition

    DECLARE_DYNAMIC(CMainFrame)
    DECLARE_MESSAGE_MAP()
};

