#include "StdAfx.h"
#include "Types.h"
#include "FileData.h"
#include "FolderData.h"
#include <Dapfor/Common/Int64DateFormat.h>


#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif


//Field map implementation. Here you declare the properties of the class that will be accessible from the grid.
//Each property has an unique identifier, and optionally may have a name, Get-function, Set-function and a format 
//to convert value, returned by the Get- function to string and vice-versa.
DF_BEGIN_FIELD_MAP(CFileData)
    DF_MFC_STRING_ID(FidName,      _T("Name"),              &CFileData::GetName,          0, 0)
    DF_MFC_STRING_ID(FidFullName,  _T("Full Name"),         &CFileData::GetFullName,      0, 0)
    DF_INT64_ID(FidSize,           _T("Size"),              &CFileData::GetSize,          0, 0)
    DF_INT64_ID(FidCreationTime,   _T("Creation time"),     &CFileData::GetCreationTime,  0, new CInt64DateFormat(CInt64DateFormat::datetime))
    DF_INT64_ID(FidLastAccessTime, _T("Last Access time"),  &CFileData::GetLastAccessTime,0, new CInt64DateFormat(CInt64DateFormat::datetime))
    DF_INT64_ID(FidLastWriteTime,  _T("Last write time"),   &CFileData::GetLastWriteTime, 0, new CInt64DateFormat(CInt64DateFormat::datetime))
    DF_LONG_ID(FidItemType,        _T("Type"),              &CFileData::GetType,          0, 0)
DF_END_FIELD_MAP()

CFileData::CFileData(const CString& name, CFolderData* parent, __int64 size, __int64 creationTime, __int64 lastAccessTime, __int64 lastWriteTime)
    : m_Name(name)
    , m_Parent(parent)
    , m_Size(size)
    , m_CreationTime(creationTime)
    , m_LastAccessTime(lastAccessTime)
    , m_LastWriteTime(lastWriteTime)
{
}

CFileData::~CFileData()
{
}

const CFolderData* CFileData::GetParent() const
{
    return m_Parent;
}

CString  CFileData::GetName() const
{
    return m_Name;
}
CString CFileData::GetFullName() const
{
    return m_Parent != 0 
        ? m_Parent->GetFullName() + CString("\\") + m_Name 
        : m_Name;
}

__int64 CFileData::GetSize() const
{
    return m_Size;
}

__int64 CFileData::GetCreationTime() const
{
    return m_CreationTime;
}
__int64 CFileData::GetLastAccessTime() const
{
    return m_LastAccessTime;
}
__int64 CFileData::GetLastWriteTime() const
{
    return m_LastWriteTime;
}

long CFileData::GetType() const
{
    return FileData;
}

void CFileData::OnUpdate(Dapfor::Common::FID fid, const Dapfor::Common::CDataObject* dataObject)
{

} 

/*__int64 CFileData::GetSize() const
{
    SHFILEINFO fi;
    SHGetFileInfo(GetFullName(), 0, &fi, sizeof(fi), 0);
    


}*/
