// HierarchicalExplorerView.cpp : implementation of the CHierarchicalExplorerView class
//

#include "stdafx.h"
#include "Resource.h"
#include "FolderData.h"
#include "FileData.h"
#include "Types.h"
#include "HierarchicalExplorerDoc.h"
#include "HierarchicalExplorerView.h"
#include "CustomDraw.h"

#include <Dapfor/Common/DataObject.h>
#include <Dapfor/GUI/GuiPreferences.h>


#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CHierarchicalExplorerView

IMPLEMENT_DYNCREATE(CHierarchicalExplorerView, CView)

BEGIN_MESSAGE_MAP(CHierarchicalExplorerView, CView)
    //{{AFX_MSG_MAP(CHierarchicalExplorerView)
    ON_WM_ERASEBKGND()
    ON_WM_SIZE()
    ON_WM_CREATE()
    ON_WM_DESTROY()
    //}}AFX_MSG_MAP
    // Standard printing commands
    ON_COMMAND(ID_INCREASE_FONT, OnIncreaseFont)
    ON_COMMAND(ID_DECREASE_FONT, OnDecreaseFont)
    ON_COMMAND(ID_EXPAND_ALL, OnExpandAll)
    ON_COMMAND(ID_COLLAPSE_ALL, OnCollapseAll)
    ON_COMMAND(ID_SHOW_LINES, OnShowLines)
    ON_UPDATE_COMMAND_UI(ID_SHOW_LINES, OnShowLinesUpdateUI)
    ON_COMMAND(ID_GRID_COLUMNS, OnSelectColumns)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CHierarchicalExplorerView construction/destruction

CHierarchicalExplorerView::CHierarchicalExplorerView()
{
    // TODO: add construction code here

}

CHierarchicalExplorerView::~CHierarchicalExplorerView()
{
}

BOOL CHierarchicalExplorerView::PreCreateWindow(CREATESTRUCT& cs)
{
    return CView::PreCreateWindow(cs);
}

/////////////////////////////////////////////////////////////////////////////
// CHierarchicalExplorerView drawing

void CHierarchicalExplorerView::OnDraw(CDC* pDC)
{
    CHierarchicalExplorerDoc* pDoc = GetDocument();
    ASSERT_VALID(pDoc);
    // TODO: add draw code for native data here
}

/////////////////////////////////////////////////////////////////////////////
// CHierarchicalExplorerView message handlers

int CHierarchicalExplorerView::OnCreate(LPCREATESTRUCT lpCreateStruct) 
{
    if (CView::OnCreate(lpCreateStruct) == -1)
        return -1;
    
    //Initialize the grid
    m_Grid.Create(0, 0, WS_VISIBLE|WS_CHILD, CRect(), this, 1000);
    
    
    //Create some header. The value 'true' in the constructor indicates, that the header will be owned by the grid and
    //the grid will handle the life time of the header. This means, that the grid will destroy the header in its destructor.
    Dapfor::GUI::CHeader* header = new Dapfor::GUI::CHeader(true);
    
    //Add some columns. To show values, returned by functions, defined in CDrive, CFolderData & CFile classes, 
    //we will use identifiers, declared in the Types.h file. The same identifiers are used by these classes.
    header->Add(new Dapfor::GUI::CColumn(FidName, _T("Name"), 270));
    header->Add(new Dapfor::GUI::CColumn(FidSize, _T("Size"), 120));
    header->Add(new Dapfor::GUI::CColumn(FidFilesCount, _T("Files count"), 80));
    header->Add(new Dapfor::GUI::CColumn(FidCreationTime,   _T("Creation time"), 130));
    header->Add(new Dapfor::GUI::CColumn(FidLastAccessTime, _T("Last access time"), 130));
    header->Add(new Dapfor::GUI::CColumn(FidLastWriteTime,  _T("Last write time"), 130));

    //The first column will be non-scrollable
    header->SetFixedColumnsCount(1);


    //Set the header
    m_Grid.SetHeader(header);

    //Set a custom draw interface
    m_Grid.SetCustomDraw(new CExplorerCustomDraw(true));
    
    //Set a double buffering
    m_Grid.SetFlickerFreeDrawing(true);
    
    m_Grid.AllowHighlight(false);

    //Prevent from notification sending for the performance reasons
    m_Grid.AllowNotifications(false);
    
    //Add listener to be notified about files and folders adding
    GetDocument()->GetFileManager().AddListener(this);
    
    return 0;
}


BOOL CHierarchicalExplorerView::OnEraseBkgnd(CDC* pDC) 
{
    //To avoid flickering we don't handle this message in the base class
    return TRUE;
}

void CHierarchicalExplorerView::OnSize(UINT nType, int cx, int cy) 
{
    //Adjust the grid to client rectangles
    CView::OnSize(nType, cx, cy);

    CRect rc;
    GetClientRect(rc);
    m_Grid.MoveWindow(rc);
}

void CHierarchicalExplorerView::OnDestroy() 
{
    GetDocument()->GetFileManager().RemoveListener(this);

    //Remove all values from the grid. Note, that the grid doesn't handle the life time of inserted objects and doesn't 
    //destroy them.
    m_Grid.DeleteAll();


    CView::OnDestroy();
}


//Called when a new drive is found
void CHierarchicalExplorerView::OnAddDrive(CFolderData& drive)
{
    m_Grid.Add(&drive);
}
//Called when a new folder is found
void CHierarchicalExplorerView::OnAddFolder(CFolderData& folder)
{
    m_Grid.Add(&folder, m_Grid.GetItem(folder.GetParent()));
}   

void CHierarchicalExplorerView::OnAddFile(CFileData& file)
{
    m_Grid.Add(&file, m_Grid.GetItem(file.GetParent()));
}

void CHierarchicalExplorerView::OnIncreaseFont()
{
    //Retrieve a font from the grid
    CFont* pfn = m_Grid.GetFont();

    //If the grid doesn't have the font, we'll take a default one
    if(pfn == 0) pfn = Dapfor::GUI::CPreferences::GetFont();
    
    //Default font can be obtained also with the next code:
    //pfn = CFont::FromHandle((HFONT)::GetStockObject(DEFAULT_GUI_FONT));
    
    if(pfn != 0)
    {
        //Get the LOGFONT data
        LOGFONT logFont;
        pfn->GetLogFont(&logFont);
        
        //Increment the font's size
        if(CDC* pDC = m_Grid.GetDC())
        {
            int fontSize = -MulDiv(logFont.lfHeight, 72, GetDeviceCaps(pDC->m_hDC, LOGPIXELSY));
            if(fontSize < 24)
            {
                logFont.lfHeight = -MulDiv(fontSize + 1, GetDeviceCaps(pDC->m_hDC, LOGPIXELSY), 72);
            }
            m_Grid.ReleaseDC(pDC);
        }
        
        //Create a temporary font
        CFont font;
        font.CreateFontIndirect(&logFont);
        
        //Set this font to the grid
        m_Grid.SetFont(&font);
        
        //Destroy the temporary font
        font.DeleteObject();
    }
}

void CHierarchicalExplorerView::OnDecreaseFont()
{
    //Retrieve a font from the grid
    CFont* pfn = m_Grid.GetFont();
    
    //If the grid doesn't have the font, we'll take a default one
    if(pfn == 0) pfn = Dapfor::GUI::CPreferences::GetFont();
    
    //Default font can be obtained also with the next code:
    //pfn = CFont::FromHandle((HFONT)::GetStockObject(DEFAULT_GUI_FONT));
    
    if(pfn != 0)
    {
        //Get the LOGFONT data
        LOGFONT logFont;
        pfn->GetLogFont(&logFont);
        
        //Decrease the font's size
        if(CDC* pDC = m_Grid.GetDC())
        {
            int fontSize = -MulDiv(logFont.lfHeight, 72, GetDeviceCaps(pDC->m_hDC, LOGPIXELSY));
            if(fontSize > 6)
            {
                logFont.lfHeight = -MulDiv(fontSize - 1, GetDeviceCaps(pDC->m_hDC, LOGPIXELSY), 72);
            }
            m_Grid.ReleaseDC(pDC);
        }
        
        //Create a temporary font
        CFont font;
        font.CreateFontIndirect(&logFont);
        
        //Set this font to the grid
        m_Grid.SetFont(&font);
        
        //Destroy the temporary font
        font.DeleteObject();
    }
}

void CHierarchicalExplorerView::OnExpandAll()
{
    m_Grid.Expand(Dapfor::GUI::GI_SCROLLABLE_ROOT, true);
}
void CHierarchicalExplorerView::OnCollapseAll()
{
    m_Grid.Collapse(Dapfor::GUI::GI_SCROLLABLE_ROOT, true);
}

void CHierarchicalExplorerView::OnShowLines()
{
    BOOL visible = (m_Grid.GetAppearance().IsVerticalLinesEnabled() || 
                   m_Grid.GetAppearance().IsHorizontalLinesEnabled());


    if(visible)
    {
        //Hide the lines
        m_Grid.GetAppearance().EnableVerticalLines(false);
        m_Grid.GetAppearance().EnableHorizontalLines(false);
    }
    else
    {
        //Show the lines
        m_Grid.GetAppearance().EnableVerticalLines(true);
        m_Grid.GetAppearance().EnableHorizontalLines(true);
    }
    m_Grid.Invalidate(FALSE);
}

void CHierarchicalExplorerView::OnShowLinesUpdateUI(CCmdUI* pCmdUI)
{
    BOOL visible = (m_Grid.GetAppearance().IsVerticalLinesEnabled() || 
                   m_Grid.GetAppearance().IsHorizontalLinesEnabled());

    pCmdUI->SetCheck(visible);
}

void CHierarchicalExplorerView::OnSelectColumns()
{
    m_Grid.ShowHeaderDialog();
}
