/////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2007-2008 Dapfor
//                                                                         
// This file is part of the Dapfor software, and may only be used, modified, and distributed 
// under the terms of the Dapfor Software License, Version 1.0.
// (See accompanying file lisense.txt or open the license at www.dapfor.com/license_agreement.aspx)
// By continuing to use, modify, or distribute this file you indicate that you have read the license 
// and understand and accept it fully.
/////////////////////////////////////////////////////////////////////////////////////////////////////

#pragma once


#include <Dapfor/Common/Common.h>

namespace Dapfor
{

namespace Common
{

//////////////////////////////////////////////////////////////////////////
/// \brief Provides the functionality to protect objects against a simultaneous access from two and more threads.
///        CSyncObject internally uses a critical section.
///
/// \class CSyncObject SyncObject.h <Dapfor/Common/SyncObject.h>
//////////////////////////////////////////////////////////////////////////
class DF_COMMON_API CSyncObject
{
public:
    CSyncObject();          //!< Constructor
    ~CSyncObject();         //!< Destructor
    
    void Lock();            //!< The function waits for the ownership of a critical section object.
    void UnLock();          //!< The function releases the ownership of a critical section object

private:
    //private constructors & methods to prevent from unwanted use
    CSyncObject(const CSyncObject&);
    CSyncObject& operator = (const CSyncObject&);

private:
    //Point implementation interface
    struct CSyncObjectImpl;
    CSyncObjectImpl* m_Impl;
};


}//namespace Common

}//namespace Dapfor

